@@ -1,28 +1,9 @@
-#!/usr/bin/env python
-#
-# Copyright 2012 Mike Wakerly <opensource@hoho.com>
-#
-# This file is part of the Pykeg package of the Kegbot project.
-# For more information on Pykeg or Kegbot, see http://kegbot.org/
-#
-# Pykeg is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 2 of the License, or
-# (at your option) any later version.
-#
-# Pykeg is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Pykeg.  If not, see <http://www.gnu.org/licenses/>.
-
-"""Kegbot Application module.
+"""Application module.
 
 Module for common logic for a command line or daemon application.
 """
 
+from builtins import object
 import warnings
 warnings.simplefilter("ignore", DeprecationWarning)
 
@@ -83,8 +64,8 @@ class App(object):
 
     try:
       self._extra_argv = FLAGS(sys.argv)  # parse flags
-    except gflags.FlagsError, e:
-      print 'Usage: %s ARGS\n%s\n\nError: %s' % (sys.argv[0], FLAGS, e)
+    except gflags.FlagsError as e:
+      print('Usage: %s ARGS\n%s\n\nError: %s' % (sys.argv[0], FLAGS, e))
       sys.exit(1)
 
     if daemon is None:
@@ -103,7 +84,7 @@ class App(object):
   def BuildAndRun(cls, name='main'):
     """Convenience class method to create and Start the app."""
     if sys.version_info < (2,4):
-      print>>sys.stderr, 'kegbot requires Python 2.4 or later; aborting'
+      print('kegbot requires Python 2.4 or later; aborting', file=sys.stderr)
       sys.exit(1)
 
     try:
